Visitor

Struct Visitor 

pub struct Visitor<'dv, D: ?Sized, V: ?Sized>(/* private fields */);
A wrapper for a Visit implementation.

Implementations

Source

impl<'dv, D: ?Sized, V: ?Sized> Visitor<'dv, D, V>

pub fn visit<N>(this: Self, node: &N)
where D: Direct<V, N>, N: ?Sized,

Complete visiting this node and return control to the Direct implementation.

pub fn visit_mut<N>(this: Self, node: &mut N)
where D: DirectMut<V, N>, N: ?Sized,

Complete visiting this node and return control to the DirectMut implementation.