Direct

Trait Direct 

pub trait Direct<V: ?Sized, N: ?Sized> {
    // Required method
    fn direct(director: Director<'_, Self, V>, node: &N);
}
Determines how to traverse the nodes within the input. This must be implemented for all node types in the input.

Required Methods

fn direct(director: Director<'_, Self, V>, node: &N)

Determines all the sub-nodes of the given node. For each sub-node, call Director::direct(&mut director, &node.my_subnode).

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors