pub trait Direct<V: ?Sized, N: ?Sized> {
// Required method
fn direct(director: Director<'_, Self, V>, node: &N);
}Expand description
Determines how to traverse the nodes within the input. This must be implemented for all node types in the input.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.